@@ -8,6 +8,7 @@ from .utils import reddit_image_utils as riu
 
 from .compact_image import CompactImage
 from .models.relative_position import RelativePosition
+from .models.vote import Vote
 # from .pil_utils import text_wrap, image, text_image
 
 class RedditImage:
@@ -20,35 +21,37 @@ class RedditImage:
         self,
 
         # FONTS
-        FONT_PATH_REGULAR: Optional[str]    = None,
-        FONT_PATH_BOLD: Optional[str]       = None,
-        FONT_PATH_BOLDEST: Optional[str]    = None,
-        FONT_PATH_THUMBNAIL: Optional[str]  = None,
+        FONT_PATH_REGULAR: Optional[str]            = None,
+        FONT_PATH_BOLD: Optional[str]               = None,
+        FONT_PATH_BOLDEST: Optional[str]            = None,
+        FONT_PATH_THUMBNAIL: Optional[str]          = None,
 
         # IMAGES
-        IMAGE_PATH_UPVOTE: Optional[str]    = None,
-        IMAGE_PATH_DOWNVOTE: Optional[str]  = None,
+        IMAGE_PATH_UPVOTE: Optional[str]            = None,
+        IMAGE_PATH_UPVOTE_COLORED: Optional[str]    = None,
+        IMAGE_PATH_DOWNVOTE: Optional[str]          = None,
+        IMAGE_PATH_DOWNVOTE_COLORED: Optional[str]  = None,
 
         # FONT SIZES
-        FONT_SIZE_HEADER: int               = 24,
-        FONT_SIZE_TITLE: int                = 50,
-        FONT_SIZE_SUBTITLE: int             = 28,
-        FONT_SIZE_COMMENT: int              = 28,
-        FONT_SIZE_VOTES: int                = 30,
+        FONT_SIZE_HEADER: int                       = 24,
+        FONT_SIZE_TITLE: int                        = 50,
+        FONT_SIZE_SUBTITLE: int                     = 28,
+        FONT_SIZE_COMMENT: int                      = 28,
+        FONT_SIZE_VOTES: int                        = 30,
 
-        FONT_SIZE_THUMBNAIL_SUB: int        = 100,
-        FONT_SIZE_THUMBNAIL_TITLE: int      = 150,
+        FONT_SIZE_THUMBNAIL_SUB: int                = 100,
+        FONT_SIZE_THUMBNAIL_TITLE: int              = 150,
 
         # COLORS
-        COLOR_BG: (int, int, int, int)      = (20, 20, 21, 255),
-        COLOR_TEXT_LIGHT: (int, int, int)   = (205, 209, 212),
-        COLOR_TEXT_DARK: (int, int, int)    = (109, 112, 113),
+        COLOR_BG: (int, int, int, int)              = (20, 20, 21, 255),
+        COLOR_TEXT_LIGHT: (int, int, int)           = (205, 209, 212),
+        COLOR_TEXT_DARK: (int, int, int)            = (109, 112, 113),
 
         # DISTANCES
-        DISTANCE: int                       = 10,
-        PADDING: Optional[int]              = None,
-        PADDING_THUMBNAIL: Optional[int]    = None,
-        COMMENT_OFFSET: Optional[int]       = None,
+        DISTANCE: int                               = 10,
+        PADDING: Optional[int]                      = None,
+        PADDING_THUMBNAIL: Optional[int]            = None,
+        COMMENT_OFFSET: Optional[int]               = None,
     ):
         self.FONT_PATH_REGULAR = FONT_PATH_REGULAR or self.__path(self.__FONTS_RESOURCES_PATH + '/regular.ttf')
         self.FONT_PATH_BOLD = FONT_PATH_BOLD or self.__path(self.__FONTS_RESOURCES_PATH + '/bold.ttf')
@@ -56,7 +59,9 @@ class RedditImage:
         self.FONT_PATH_THUMBNAIL = FONT_PATH_THUMBNAIL or self.__path(self.__FONTS_RESOURCES_PATH + '/thumbnail.ttf')
 
         self.IMAGE_PATH_UPVOTE = IMAGE_PATH_UPVOTE or self.__path(self.__IMAGES_RESOURCES_PATH + '/up.png')
+        self.IMAGE_PATH_UPVOTE_COLORED = IMAGE_PATH_UPVOTE_COLORED or self.__path(self.__IMAGES_RESOURCES_PATH + '/up-colored.png')
         self.IMAGE_PATH_DOWNVOTE = IMAGE_PATH_DOWNVOTE or self.__path(self.__IMAGES_RESOURCES_PATH + '/down.png')
+        self.IMAGE_PATH_DOWNVOTE_COLORED = IMAGE_PATH_DOWNVOTE_COLORED or self.__path(self.__IMAGES_RESOURCES_PATH + '/down-colored.png')
 
         self.FONT_SIZE_HEADER = FONT_SIZE_HEADER
         self.FONT_SIZE_TITLE = FONT_SIZE_TITLE
@@ -87,13 +92,14 @@ class RedditImage:
         poster_username: str,
         timestamp: float,
         width: int,
-        height: Optional[int] = None
+        height: Optional[int] = None,
+        user_vote: Vote = Vote.NONE
     ) -> Image:
         sub_font    = ImageFont.truetype(self.FONT_PATH_BOLDEST, self.FONT_SIZE_HEADER)
         header_font = ImageFont.truetype(self.FONT_PATH_BOLD,    self.FONT_SIZE_HEADER)
         title_font  = ImageFont.truetype(self.FONT_PATH_BOLD,    self.FONT_SIZE_TITLE)
 
-        votes_img = self.__votes_image(64, upvotes=upvotes)
+        votes_img = self.__votes_image(64, upvotes=upvotes, user_vote=user_vote)
         ci = CompactImage(self.DISTANCE, self.PADDING, bg_color=self.COLOR_BG, image=votes_img)
 
         sub_img = piu.text_image(riu.sub(sub), sub_font, fg_color=self.COLOR_TEXT_LIGHT, wrap_instead_of_font_downscale=False)
@@ -183,13 +189,14 @@ class RedditImage:
         timestamp: float,
         width: int,
         height: Optional[int] = None,
-        comment_level: int = 0
+        comment_level: int = 0,
+        user_vote: Vote = Vote.NONE
     ) -> Image:
         username_font   = ImageFont.truetype(self.FONT_PATH_BOLDEST, self.FONT_SIZE_HEADER)
         header_font     = ImageFont.truetype(self.FONT_PATH_BOLD,    self.FONT_SIZE_HEADER)
         comment_font    = ImageFont.truetype(self.FONT_PATH_BOLD, self.FONT_SIZE_COMMENT)
 
-        votes_img = self.__votes_image(40)
+        votes_img = self.__votes_image(40, user_vote=user_vote)
         ci = CompactImage(self.DISTANCE, self.PADDING, bg_color=self.COLOR_BG)
         ci.add_image(votes_img, extra_distance_x=comment_level*self.COMMENT_OFFSET)
 
@@ -220,7 +227,7 @@ class RedditImage:
 
             return self.___footer_img
 
-    def __votes_image(self, width: int, upvotes: Optional[int] = None) -> Image:
+    def __votes_image(self, width: int, upvotes: Optional[int] = None, user_vote: Vote = Vote.NONE) -> Image:
         img_upvote = Image.open(self.IMAGE_PATH_UPVOTE)
         img_upvote.thumbnail((width, width), Image.ANTIALIAS)
         img_downvote = Image.open(self.IMAGE_PATH_DOWNVOTE)
